==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualGatewaySpecListenerTlCertificate.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property acms
 * @property files
 * @property sds
 */
public data class GetVirtualGatewaySpecListenerTlCertificate(
    public val acms: List<GetVirtualGatewaySpecListenerTlCertificateAcm>,
    public val files: List<GetVirtualGatewaySpecListenerTlCertificateFile>,
    public val sds: List<GetVirtualGatewaySpecListenerTlCertificateSd>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualGatewaySpecListenerTlCertificate):
            GetVirtualGatewaySpecListenerTlCertificate = GetVirtualGatewaySpecListenerTlCertificate(
            acms = javaType.acms().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerTlCertificateAcm.Companion.toKotlin(args0)
                })
            }),
            files = javaType.files().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerTlCertificateFile.Companion.toKotlin(args0)
                })
            }),
            sds = javaType.sds().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerTlCertificateSd.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualGatewaySpecListenerTlCertificate.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property acms
 * @property files
 * @property sds
 */
public data class GetVirtualGatewaySpecListenerTlCertificate(
    public val acms: List<GetVirtualGatewaySpecListenerTlCertificateAcm>,
    public val files: List<GetVirtualGatewaySpecListenerTlCertificateFile>,
    public val sds: List<GetVirtualGatewaySpecListenerTlCertificateSd>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualGatewaySpecListenerTlCertificate): GetVirtualGatewaySpecListenerTlCertificate = GetVirtualGatewaySpecListenerTlCertificate(
            acms = javaType.acms().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerTlCertificateAcm.Companion.toKotlin(args0)
                })
            }),
            files = javaType.files().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerTlCertificateFile.Companion.toKotlin(args0)
                })
            }),
            sds = javaType.sds().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualGatewaySpecListenerTlCertificateSd.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
